@@ -57,11 +57,6 @@ extern const ScFormulaCell* pLastFormulaTreeTop;	// cellform.cxx Err527 WorkArou
 
 // STATIC DATA -----------------------------------------------------------
 
-#ifdef erDEBUG
-ULONG erCountBCAInserts = 0;
-ULONG erCountBCAFinds = 0;
-#endif
-
 // -----------------------------------------------------------------------
 
 /*N*/ void ScDocument::StartListeningArea( const ScRange& rRange,
@@ -332,12 +327,11 @@ ULONG erCountBCAFinds = 0;
 /*N*/ 		ScBroadcasterList* pBC;
 /*N*/ 		ScFormulaCell* pTrack;
 /*N*/ 		ScFormulaCell* pNext;
-/*N*/ 		BOOL bIsChanged = TRUE;
 /*N*/ 		pTrack = pFormulaTrack;
 /*N*/ 		do
 /*N*/ 		{
 /*N*/ 			ScHint aHint( nHintId, pTrack->aPos, pTrack );
-/*N*/ 			if ( pBC = pTrack->GetBroadcaster() )
+/*N*/ 			if (( pBC = pTrack->GetBroadcaster() ))
 /*N*/ 				pBC->Broadcast( aHint );
 /*N*/ 			pBASM->AreaBroadcast( aHint );
 /*N*/ 			//	Repaint fuer bedingte Formate mit relativen Referenzen:
@@ -361,7 +355,7 @@ ULONG erCountBCAFinds = 0;
 /*?*/ 			SetForcedFormulas( TRUE );
 /*?*/ 			if ( bAutoCalc && !IsAutoCalcShellDisabled() && !IsInInterpreter()
 /*?*/ 					&& !IsCalculatingFormulaTree() )
-{DBG_BF_ASSERT(0, "STRIP"); }//STRIP001 /*?*/ 				CalcFormulaTree( TRUE );
+{DBG_BF_ASSERT(0, "STRIP"); }
 /*?*/ 			else
 /*?*/ 				SetForcedFormulaPending( TRUE );
 /*N*/ 		}
@@ -380,7 +374,7 @@ ULONG erCountBCAFinds = 0;
 /*N*/ }
 
 /*N*/ void ScDocument::UpdateBroadcastAreas( UpdateRefMode eUpdateRefMode,
-/*N*/ 		const ScRange& rRange, short nDx, short nDy, short nDz
+/*N*/ 		const ScRange& /*rRange*/, short nDx, short nDy, short nDz
 /*N*/ 	)
 /*N*/ {
 /*N*/ 	BOOL bExpandRefsOld = IsExpandRefs();
@@ -398,7 +392,7 @@ ULONG erCountBCAFinds = 0;
 /*?*/ 		if ( IsAutoCalcShellDisabled() )
 /*?*/ 			SetForcedFormulaPending( TRUE );
 /*?*/ 		else if ( !IsInInterpreter() )
-DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 			CalcFormulaTree( TRUE );
+DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/ }
 
