@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,9 +26,6 @@
  *
  ************************************************************************/
 
-#ifdef PCH
-#endif
-
 #ifdef _MSC_VER
 #pragma hdrstop
 #endif
@@ -87,7 +85,7 @@ namespace binfilter {
 /*N*/ 		bDummyUpperLeft( FALSE ),
 /*N*/ 		bValid( TRUE )
 /*N*/ {
-/*?*/ 	DBG_BF_ASSERT(0, "STRIP"); //STRIP001 if ( aRangeListRef.Is() )
+/*?*/ 	DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 /*N*/ 
 /*N*/ ScChartArray::ScChartArray( const ScChartArray& rArr ) :
@@ -198,10 +196,10 @@ namespace binfilter {
 /*N*/ 					if ( bNewChart )
 /*N*/ 					{
 /*N*/ 						bDummyUpperLeft = ( aOpt.GetChar(2) != '0' );
-/*N*/ 						xub_StrLen nInd = 4;	// 111;
-/*N*/ 						eGlue = (ScChartGlue) aOpt.GetToken( 0, cTok, nInd ).ToInt32();
-/*N*/ 						nStartCol = (USHORT) aOpt.GetToken( 0, cTok, nInd ).ToInt32();
-/*N*/ 						nStartRow = (USHORT) aOpt.GetToken( 0, cTok, nInd ).ToInt32();
+/*N*/ 						xub_StrLen nLclInd = 4;	// 111;
+/*N*/ 						eGlue = (ScChartGlue) aOpt.GetToken( 0, cTok, nLclInd ).ToInt32();
+/*N*/ 						nStartCol = (USHORT) aOpt.GetToken( 0, cTok, nLclInd ).ToInt32();
+/*N*/ 						nStartRow = (USHORT) aOpt.GetToken( 0, cTok, nLclInd ).ToInt32();
 /*N*/ 						bInitOk = TRUE;
 /*N*/ 					}
 /*N*/ 				}
@@ -268,7 +266,7 @@ namespace binfilter {
 /*N*/ 	ScRangePtr pR;
 /*N*/ 	if ( aRangeListRef->Count() <= 1 )
 /*N*/ 	{
-/*?*/ 		if ( pR = aRangeListRef->First() )
+/*?*/ 		if (( pR = aRangeListRef->First() ))
 /*?*/ 		{
 /*?*/ 			if ( pR->aStart.Tab() == pR->aEnd.Tab() )
 /*?*/ 				eGlue = SC_CHARTGLUE_NONE;
@@ -284,7 +282,7 @@ namespace binfilter {
 /*?*/ 		}
 /*?*/ 		return;
 /*N*/ 	}
-/*N*/ 	ULONG nOldPos = aRangeListRef->GetCurPos();
+/*N*/ 	aRangeListRef->GetCurPos();
 /*N*/ 
 /*N*/ 	pR = aRangeListRef->First();
 /*N*/ 	nStartCol = pR->aStart.Col();
@@ -306,7 +304,7 @@ namespace binfilter {
 /*N*/ 			nEndRow = n2;
 /*N*/ 		if ( (nTmp = n2 - n1 + 1) > nMaxRows )
 /*N*/ 			nMaxRows = nTmp;
-/*N*/ 	} while ( pR = aRangeListRef->Next() );
+/*N*/ 	} while (( pR = aRangeListRef->Next() ));
 /*N*/ 	USHORT nC = nEndCol - nStartCol + 1;
 /*N*/ 	if ( nC == 1 )
 /*N*/ 	{
@@ -599,7 +597,6 @@ namespace binfilter {
 /*N*/ 			{
 /*N*/ 				aString = ScGlobal::GetRscString(STR_COLUMN);
 /*N*/ 				aString += ' ';
-/*N*/ //                aString += String::CreateFromInt32( pCols[nCol]+1 );
 /*N*/                 ScAddress aPos( pCols[ nCol ], 0, 0 );
 /*N*/                 aPos.Format( aColStr, SCA_VALID_COL, NULL );
 /*N*/                 aString += aColStr;
@@ -662,7 +659,7 @@ namespace binfilter {
 /*N*/         SetExtraStrings( *pMemChart );
 /*N*/ 	}
 /*N*/ 	else
-/*N*/ 		DBG_ERROR("SchDLL::NewMemChart gibt 0 zurueck!");
+/*N*/ 		OSL_FAIL("SchDLL::NewMemChart gibt 0 zurueck!");
 /*N*/ 
 /*N*/ 		//	Aufraeumen
 /*N*/ 
@@ -747,7 +744,6 @@ namespace binfilter {
 /*?*/ 					nPosCol++;
 /*?*/                 ScAddress aPos( nPosCol - 1, 0, 0 );
 /*?*/                 aPos.Format( aColStr, SCA_VALID_COL, NULL );
-/*?*/ //                aString += String::CreateFromInt32( nPosCol );
 /*?*/                 aString += aColStr;
 /*N*/ 			}
 /*N*/ 			pMemChart->SetColText(nCol, aString);
@@ -809,13 +805,13 @@ namespace binfilter {
 /*N*/ 		SvNumberFormatter* pFormatter = pDocument->GetFormatTable();
 /*N*/ 		if (pFormatter)
 /*N*/ 		{
-/*N*/ 			ULONG nIndex = 0;
+/*N*/ 			ULONG nLclIndex = 0;
 /*N*/ 			ULONG nCount = pPositionMap->GetCount();
 /*N*/ 			const ScAddress* pPos;
 /*N*/ 			do
 /*N*/ 			{
-/*N*/ 				pPos = pPositionMap->GetPosition( nIndex );
-/*N*/ 			} while ( !pPos && ++nIndex < nCount );
+/*N*/ 				pPos = pPositionMap->GetPosition( nLclIndex );
+/*N*/ 			} while ( !pPos && ++nLclIndex < nCount );
 /*N*/ 			ULONG nFormat = ( pPos ? pDocument->GetNumberFormat( *pPos ) : 0 );
 /*N*/ 			pMemChart->SetDataType( pFormatter->GetType( nFormat ) );
 /*N*/ 		}
@@ -827,7 +823,7 @@ namespace binfilter {
 /*N*/         SetExtraStrings( *pMemChart );
 /*N*/ 	}
 /*N*/ 	else
-/*N*/ 		DBG_ERROR("SchDLL::NewMemChart gibt 0 zurueck!");
+/*N*/ 		OSL_FAIL("SchDLL::NewMemChart gibt 0 zurueck!");
 /*N*/ 
 /*N*/ 	return pMemChart;
 /*N*/ }
@@ -836,38 +832,6 @@ namespace binfilter {
 /*N*/ {
 /*N*/     ScRangePtr pR;
 /*N*/ 	USHORT nCol1, nRow1, nTab1, nCol2, nRow2, nTab2;
-/*N*/ #if 0
-/* now this is done in SchMemChart::ConvertChartRangeForCalc() for SO5 file format
-    const sal_Unicode cTok = ';';
-    String aRef;
-    for ( pR = aRangeListRef->First(); pR; pR = aRangeListRef->Next() )
-    {
-        pR->GetVars( nCol1, nRow1, nTab1, nCol2, nRow2, nTab2 );
-        if ( aRef.Len() )
-            aRef += cTok;
-        aRef += String::CreateFromInt32( nTab1 );
-        // hier ',' als TokenSep damit alte Versionen (<341/342) das ueberlesen
-        aRef += ',';  aRef += String::CreateFromInt32( nTab2 );
-        aRef += cTok; aRef += String::CreateFromInt32( nCol1 );
-        aRef += cTok; aRef += String::CreateFromInt32( nRow1 );
-        aRef += cTok; aRef += String::CreateFromInt32( nCol2 );
-        aRef += cTok; aRef += String::CreateFromInt32( nRow2 );
-    }
-
-    String aFlags = bColHeaders ? '1' : '0';
-    aFlags += bRowHeaders ? '1' : '0';
-    aFlags += bDummyUpperLeft ? '1' : '0';
-    aFlags += cTok;
-    aFlags += String::CreateFromInt32( eGlue );
-    aFlags += cTok;
-    aFlags += String::CreateFromInt32( nStartCol );
-    aFlags += cTok;
-    aFlags += String::CreateFromInt32( nStartRow );
-
-    rMem.SomeData1() = aRef;
-    rMem.SomeData2() = aFlags;
-*/
-/*N*/ #endif
 /*N*/ 
 /*N*/     String aSheetNames;
 /*N*/     SchChartRange aChartRange;
@@ -888,13 +852,13 @@ namespace binfilter {
 /*N*/             aCell.mnRow = nRow2;
 /*N*/             aCellRangeAddress.maLowerRight.maCells.push_back( aCell );
 /*N*/             aCellRangeAddress.mnTableNumber = nTab;
-/*N*/             String aName;
-/*N*/             pDocument->GetName( nTab, aName );
-/*N*/             aCellRangeAddress.msTableName = aName;
+/*N*/             String aLclName;
+/*N*/             pDocument->GetName( nTab, aLclName );
+/*N*/             aCellRangeAddress.msTableName = aLclName;
 /*N*/             aChartRange.maRanges.push_back( aCellRangeAddress );
 /*N*/             if ( aSheetNames.Len() )
 /*N*/                 aSheetNames += ';';
-/*N*/             aSheetNames += aName;
+/*N*/             aSheetNames += aLclName;
 /*N*/         }
 /*N*/     }
 /*N*/     rMem.SetChartRange( aChartRange );
@@ -1007,7 +971,7 @@ namespace binfilter {
 /*N*/ 
 /*N*/ 	// Anzahl der Daten
 /*N*/ 	nColCount = (USHORT) pCols->Count();
-/*N*/ 	if ( pCol = (Table*) pCols->First() )
+/*N*/ 	if (( pCol = (Table*) pCols->First() ))
 /*N*/ 	{
 /*N*/ 		if ( bDummyUpperLeft )
 /*?*/ 			pCol->Insert( 0, (void*)0 );		// Dummy fuer Beschriftung
@@ -1057,7 +1021,7 @@ namespace binfilter {
 /*?*/ 			{
 /*?*/ 				ULONG nKey = pFirstCol->GetCurKey();
 /*?*/ 				pCols->First();
-/*?*/ 				while ( pCol = (Table*) pCols->Next() )
+/*?*/ 				while (( pCol = (Table*) pCols->Next() ))
 /*?*/ 					pCol->Insert( nKey, (void*)0 );		// keine Daten
 /*?*/ 			}
 /*?*/ 		}
@@ -1077,12 +1041,12 @@ namespace binfilter {
 
 /*N*/ ScChartPositionMap::ScChartPositionMap( USHORT nChartCols, USHORT nChartRows,
 /*N*/ 			USHORT nColAdd, USHORT nRowAdd, Table& rCols ) :
-/*N*/ 		nCount( (ULONG) nChartCols * nChartRows ),
-/*N*/ 		nColCount( nChartCols ),
-/*N*/ 		nRowCount( nChartRows ),
 /*N*/ 		ppData( new ScAddress* [ nChartCols * nChartRows ] ),
 /*N*/ 		ppColHeader( new ScAddress* [ nChartCols ] ),
-/*N*/ 		ppRowHeader( new ScAddress* [ nChartRows ] )
+/*N*/ 		ppRowHeader( new ScAddress* [ nChartRows ] ),
+/*N*/ 		nCount( (ULONG) nChartCols * nChartRows ),
+/*N*/ 		nColCount( nChartCols ),
+/*N*/ 		nRowCount( nChartRows )
 /*N*/ {
 /*N*/ 	DBG_ASSERT( nColCount && nRowCount, "ScChartPositionMap without dimension" );
 /*N*/ #ifdef WIN
@@ -1090,7 +1054,7 @@ namespace binfilter {
 /*N*/ #endif
 /*N*/ 
 /*N*/ 	ScAddress* pPos;
-/*N*/ 	USHORT nCol, nRow;
+/*N*/ 	USHORT nCol;
 /*N*/ 
 /*N*/ 	Table* pCol = (Table*) rCols.First();
 /*N*/ 
@@ -1100,7 +1064,7 @@ namespace binfilter {
 /*N*/ 		pPos = (ScAddress*) pCol->Next();
 /*N*/ 	if ( nColAdd )
 /*N*/ 	{	// eigenstaendig
-/*N*/ 		for ( nRow = 0; nRow < nRowCount; nRow++ )
+/*N*/ 		for ( USHORT nRow = 0; nRow < nRowCount; nRow++ )
 /*N*/ 		{
 /*N*/ 			ppRowHeader[ nRow ] = pPos;
 /*N*/ 			pPos = (ScAddress*) pCol->Next();
@@ -1108,7 +1072,7 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ 	else
 /*N*/ 	{	// Kopie
-/*?*/ 		for ( nRow = 0; nRow < nRowCount; nRow++ )
+/*?*/ 		for ( USHORT nRow = 0; nRow < nRowCount; nRow++ )
 /*?*/ 		{
 /*?*/ 			ppRowHeader[ nRow ] = ( pPos ? new ScAddress( *pPos ) : NULL );
 /*?*/ 			pPos = (ScAddress*) pCol->Next();
@@ -1140,7 +1104,7 @@ namespace binfilter {
 /*N*/ 		else
 /*N*/ 		{
 /*?*/ 			ppColHeader[ nCol ] = NULL;
-/*?*/ 			for ( nRow = 0; nRow < nRowCount; nRow++, nIndex++ )
+/*?*/ 			for ( USHORT nRow = 0; nRow < nRowCount; nRow++, nIndex++ )
 /*?*/ 			{
 /*?*/ 				ppData[ nIndex ] = NULL;
 /*?*/ 			}
@@ -1201,3 +1165,5 @@ namespace binfilter {
 /*N*/ }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
