@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -53,7 +53,6 @@
 #include "sfxsids.hrc"
 #include "printer.hxx"
 #include "objsh.hxx"
-#include "docinf.hxx"
 #include "docfile.hxx"
 #include "openflag.hxx"
 #include "app.hxx"
@@ -110,34 +109,12 @@ using namespace ::com::sun::star::frame;
 /*N*/     { "TemplateDate"    , 12, MID_DOCINFO_TEMPLATEDATE, &::getCppuType((const ::com::sun::star::util::DateTime*)0),PROPERTY_MAYBEVOID, 0 },
 /*N*/ 	{ "Theme"			, 5 , MID_DOCINFO_SUBJECT, &::getCppuType((const ::rtl::OUString*)0), PROPERTY_UNBOUND, 0 },
 /*N*/ 	{ "Title"			, 5 , WID_TITLE,          &::getCppuType((const ::rtl::OUString*)0), PROPERTY_UNBOUND, 0 },
-/*N*/ 	{0,0,0,0,0}
+/*N*/ 	{0,0,0,0,0,0}
 /*N*/ };
 
 //-----------------------------------------------------------------------------
 /*N*/ SFX_IMPL_XINTERFACE_5( SfxDocumentInfoObject, OWeakObject, ::com::sun::star::document::XDocumentInfo, ::com::sun::star::lang::XComponent, ::com::sun::star::beans::XPropertySet, ::com::sun::star::beans::XFastPropertySet, ::com::sun::star::beans::XPropertyAccess )
 /*N*/ SFX_IMPL_XTYPEPROVIDER_5( SfxDocumentInfoObject, ::com::sun::star::document::XDocumentInfo, ::com::sun::star::lang::XComponent, ::com::sun::star::beans::XPropertySet, ::com::sun::star::beans::XFastPropertySet, ::com::sun::star::beans::XPropertyAccess )
-/*
-::com::sun::star::uno::Reference< ::com::sun::star::reflection::XIdlClass >  SfxDocumentInfoObject::getStaticIdlClass()
-{
-    // Global Method, must be guarded (multithreading)
-    MutexGuard aGuard( Mutex::getGlobalMutex() );
-    {
-        // use the standard class implementation of the usr library
-        static ::com::sun::star::uno::Reference< ::com::sun::star::reflection::XIdlClass >  xClass =
-        createStandardClass(
-            "com.sun.star.comp.sfx2.DocumentInfo",
-            OWeakObject::getStaticIdlClass(),
-            4,
-            ::getCppuType((const ::com::sun::star::lang::XComponent*)0),
-            ::getCppuType((const ::com::sun::star::document::XDocumentInfo*)0),
-            ::getCppuType((const ::com::sun::star::beans::XPropertyAccess*)0),
-            ::getCppuType((const ::com::sun::star::beans::XPropertySet*)0),
-            ::getCppuType((const ::com::sun::star::beans::XFastPropertySet*)0) );
-
-        return xClass;
-    }
-}
-*/
 //-----------------------------------------------------------------------------
 /*N*/ struct SfxDocumentInfoObject_Impl
 /*N*/ {
@@ -156,10 +133,10 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ SfxDocumentInfoObject::SfxDocumentInfoObject( sal_Bool bStandalone )
 /*N*/ 	: _aPropSet( aDocInfoPropertyMap_Impl )
-/*N*/ 	, _pInfo( NULL )
-/*N*/ 	, _pFilter( NULL )
 /*N*/ 	, _bStandalone( bStandalone )
 /*N*/ 	, _pImp( new SfxDocumentInfoObject_Impl( NULL ) )
+/*N*/ 	, _pInfo( NULL )
+/*N*/ 	, _pFilter( NULL )
 /*N*/ {
         _pInfo = new SfxDocumentInfo;
 /*N*/ }
@@ -168,10 +145,10 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ SfxDocumentInfoObject::SfxDocumentInfoObject( SfxObjectShell *pObjSh )
 /*N*/ 	: _aPropSet( aDocInfoPropertyMap_Impl )
-/*N*/ 	, _pInfo( 0 )
-/*N*/ 	, _pFilter( NULL )
 /*N*/ 	, _bStandalone( sal_False )
 /*N*/ 	, _pImp( new SfxDocumentInfoObject_Impl( pObjSh ) )
+/*N*/ 	, _pInfo( 0 )
+/*N*/ 	, _pFilter( NULL )
 /*N*/ {
 /*N*/ 	if ( pObjSh )
 /*N*/ 	{
@@ -197,12 +174,6 @@ using namespace ::com::sun::star::frame;
 /*N*/ {
 /*N*/ 	::com::sun::star::lang::EventObject aEvent( (::cppu::OWeakObject *)this );
 /*N*/ 	_pImp->_aDisposeContainer.disposeAndClear( aEvent );
-
-/*
-    _xCurrent = ::com::sun::star::uno::Reference< ::com::sun::star::frame::XController > ();
-    for ( sal_uInt32 n = _aControllers.ge.getLength(); n; --n )
-        SequenceRemoveElementAt( _aControllers, n-1 );
-*/
 /*N*/ }
 
 //-----------------------------------------------------------------------------
@@ -250,22 +221,22 @@ using namespace ::com::sun::star::frame;
 
 //-----------------------------------------------------------------------------
 
-/*N*/ void SAL_CALL  SfxDocumentInfoObject::addPropertyChangeListener(const ::rtl::OUString& aPropertyName, const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertyChangeListener > & aListener) throw( ::com::sun::star::uno::RuntimeException )
+/*N*/ void SAL_CALL  SfxDocumentInfoObject::addPropertyChangeListener(const ::rtl::OUString& /*aPropertyName*/, const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertyChangeListener > & /*aListener*/) throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {}
 
 //-----------------------------------------------------------------------------
 
-/*N*/ void SAL_CALL  SfxDocumentInfoObject::removePropertyChangeListener(const ::rtl::OUString& aPropertyName, const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertyChangeListener > & aListener) throw( ::com::sun::star::uno::RuntimeException )
+/*N*/ void SAL_CALL  SfxDocumentInfoObject::removePropertyChangeListener(const ::rtl::OUString& /*aPropertyName*/, const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertyChangeListener > & /*aListener*/) throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {}
 
 //-----------------------------------------------------------------------------
 
-/*N*/ void SAL_CALL  SfxDocumentInfoObject::addVetoableChangeListener(const ::rtl::OUString& aPropertyName, const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XVetoableChangeListener > & aListener) throw( ::com::sun::star::uno::RuntimeException )
+/*N*/ void SAL_CALL  SfxDocumentInfoObject::addVetoableChangeListener(const ::rtl::OUString& /*aPropertyName*/, const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XVetoableChangeListener > & /*aListener*/) throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {}
 
 //-----------------------------------------------------------------------------
 
-/*N*/ void SAL_CALL  SfxDocumentInfoObject::removeVetoableChangeListener(const ::rtl::OUString& aPropertyName, const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XVetoableChangeListener > & aListener) throw( ::com::sun::star::uno::RuntimeException )
+/*N*/ void SAL_CALL  SfxDocumentInfoObject::removeVetoableChangeListener(const ::rtl::OUString& /*aPropertyName*/, const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XVetoableChangeListener > & /*aListener*/) throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {}
 /*N*/
 /*N*/ ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > SAL_CALL  SfxDocumentInfoObject::getPropertyValues( void ) throw( ::com::sun::star::uno::RuntimeException )
@@ -491,7 +462,7 @@ using namespace ::com::sun::star::frame;
 /*N*/ 	}
 /*N*/ 	else if ( aValue.getValueType() == ::getBooleanCppuType() )
 /*N*/ 	{
-/*N*/ 		sal_Bool bBoolVal ;
+/*N*/ 		sal_Bool bBoolVal(sal_False);
 /*N*/ 		aValue >>= bBoolVal ;
 /*N*/ 		switch ( nHandle )
 /*N*/ 		{
@@ -507,8 +478,8 @@ using namespace ::com::sun::star::frame;
 /*N*/ 	}
 /*N*/ 	else if ( aValue.getValueType() == ::getCppuType((const sal_Int32*)0) )
 /*N*/ 	{
-/*N*/ 		long nIntVal ;
-/*N*/ 		aValue >>= nIntVal ;
+/*N*/ 		long nIntVal(0);
+/*N*/ 		aValue >>= nIntVal;
 /*N*/ 		switch ( nHandle )
 /*N*/ 		{
 /*N*/ 			case MID_DOCINFO_AUTOLOADSECS:
@@ -522,8 +493,8 @@ using namespace ::com::sun::star::frame;
 /*N*/ 	}
 /*N*/ 	else if ( aValue.getValueType() == ::getCppuType((const sal_Int16*)0) )
 /*N*/ 	{
-/*N*/ 		short nIntVal ;
-/*N*/ 		aValue >>= nIntVal ;
+/*N*/ 		short nIntVal(0);
+/*N*/ 		aValue >>= nIntVal;
 /*N*/ 		switch ( nHandle )
 /*N*/ 		{
 /*N*/ 			case MID_DOCINFO_REVISION:
@@ -789,7 +760,7 @@ using namespace ::com::sun::star::frame;
 /*N*/ 	// Filter-Detection wegen FileFormat-Version
 /*N*/ 	_pFilter = 0;
 /*N*/ 	if ( 0 != SFX_APP()->GetFilterMatcher().GuessFilter( *_pMedium, &_pFilter )
-/*N*/ 			|| !bWrite && !_pFilter )
+/*N*/ 			|| (!bWrite && !_pFilter) )
 /*N*/ 		// unbekanntes Dateiformat
 /*N*/ 		return NULL;
 /*N*/
@@ -930,32 +901,6 @@ Reference< XInterface > SAL_CALL bf_BinaryDocInfo_createInstance(const Reference
 }
 
 
-//=============================================================================
-/* ASMUSS
-#ifdef TEST_CODE
-    // Testcode fuer DocumentInfoObject
-    // Einmal zum Holen
-    ::com::sun::star::uno::Reference< XServiceManager >  xMan = getGlobalServiceManager();
-    ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Uik > aIfaces( 2 );
-    aIfaces.getArray()[0] = ::getCppuType((const Reference< ::com::sun::star::document::XDocumentInfo >*)0);
-    aIfaces.getArray()[1] = ::getCppuType((const Reference< ::com::sun::star::beans::XFastPropertySet >*)0);
-    ::com::sun::star::uno::Reference< XServiceProvider >  xSSI = xMan->getServiceProvider(
-            "com.sun.star.document.DocumentInfo", aIfaces, ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Uik >() );
-// automatisch auskommentiert - [getIdlClass(es) or queryInterface] - Bitte XTypeProvider benutzen!
-//	::com::sun::star::uno::Reference< ::com::sun::star::document::XDocumentInfo >  xInfo = (::com::sun::star::document::XDocumentInfo*) xSSI->newInstance()->queryInterface( ::getCppuType((const Reference< ::com::sun::star::document::XDocumentInfo >*)0) );
-
-// automatisch auskommentiert - [getIdlClass(es) or queryInterface] - Bitte XTypeProvider benutzen!
-//	::com::sun::star::uno::Reference< ::com::sun::star::beans::XFastPropertySet >  xProps = (::com::sun::star::beans::XFastPropertySet*) xInfo->queryInterface( ::getCppuType((const Reference< ::com::sun::star::beans::XFastPropertySet >*)0) );
-
-
-    // Laden und Werte auslesen
-    xInfo->load( StringToOUString( aURL, CHARSET_SYSTEM ) );
-    ::com::sun::star::uno::Any aValue = xProps->getFastPropertyValue( WID_FROM );
-    String aAuthor = OUStringToString( aValue.getString(), CHARSET_SYSTEM );
-#endif
-*/
-
-
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
