@@ -31,7 +31,7 @@
 #pragma hdrstop
 #endif
 
-#include "errhdl.hxx"
+#include <osl/diagnose.h>
 #include "paratr.hxx"
 
 #include <horiornt.hxx>
@@ -138,7 +138,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*M*/ 					case SVX_LINE_SPACE_FIX:
 /*M*/ 						nFirstLineOfs = pSpace->GetLineHeight();
 /*M*/ 					break;
-/*M*/ 					default: ASSERT( sal_False, ": unknown LineSpaceRule" );
+/*M*/ 					default: OSL_FAIL( ": unknown LineSpaceRule" );
 /*M*/ 				}
 /*M*/ 				switch( pSpace->GetInterLineSpaceRule() )
 /*M*/ 				{
@@ -164,7 +164,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*M*/ 						nFirstLineOfs += pSpace->GetInterLineSpace();
 /*M*/ 						break;
 /*M*/ 					}
-/*M*/ 					default: ASSERT( sal_False, ": unknown InterLineSpaceRule" );
+/*M*/ 					default: OSL_FAIL( ": unknown InterLineSpaceRule" );
 /*M*/ 				}
 /*M*/ 			}
 /*M*/ 		}
@@ -337,7 +337,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/ 		{
 /*N*/ 			nX += pPor->Width();
 /*N*/ 			if ( pPor->InSpaceGrp() && nSpaceAdd )
-                    {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/ 				nX += pPor->CalcSpacing( nSpaceAdd, aInf );
+                    {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 			if( bNoTxt )
 /*N*/ 				nFirst = nX;
 /*N*/ 			// 8670: EndPortions zaehlen hier einmal als TxtPortions.
@@ -420,7 +420,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/                 if ( aInf.GetIdx() + pPor->GetLen() < nOfst + nExtra )
 /*N*/ 				{
 /*N*/ 					if ( pPor->InSpaceGrp() && nSpaceAdd )
-                            {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*N*/ 						nX += pPor->PrtWidth() +
+                            {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 					else
 /*N*/ 					{
 /*N*/                         if( pPor->InFixMargGrp() && ! pPor->IsMarginPortion() )
@@ -468,7 +468,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/ 				{
 /*N*/ 					if( pPor->IsMultiPortion() )
 /*N*/ 					{
-                            DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ #ifdef VERTICAL_LAYOUT
+                            DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 					}
 /*N*/ 					if ( pPor->PrtWidth() )
 /*N*/ 					{
@@ -509,7 +509,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/ 
 /*N*/ 		if( pPor )
 /*N*/ 		{
-/*N*/             ASSERT( !pPor->InNumberGrp() || bInsideFirstField, "Number surprise" );
+/*N*/             OSL_ENSURE( !pPor->InNumberGrp() || bInsideFirstField, "Number surprise" );
 /*N*/ 			sal_Bool bEmptyFld = sal_False;
 /*N*/ 			if( pPor->InFldGrp() && pPor->GetLen() )
 /*N*/ 			{
@@ -520,7 +520,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*?*/ 					SwLinePortion *pNext = pTmp->GetPortion();
 /*?*/ 					while( pNext && !pNext->InFldGrp() )
 /*?*/ 					{
-/*?*/ 						ASSERT( !pNext->GetLen(), "Where's my field follow?" );
+/*?*/ 						OSL_ENSURE( !pNext->GetLen(), "Where's my field follow?" );
 /*?*/ 						nAddX += pNext->Width();
 /*?*/ 						pNext = pNext->GetPortion();
 /*?*/ 					}
@@ -661,7 +661,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/                 if ( pCMS->pSpecialPos )
 /*N*/                 {
 /*N*/                     // apply attributes to font
-                        DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/                     Seek( nOfst );
+                        DBG_BF_ASSERT(0, "STRIP");
 /*N*/                 }
 /*N*/             }
 /*N*/         }
@@ -679,7 +679,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/ 				pCMS->aRealHeight.X() = nTmpAscent - nPorAscent;
 /*N*/ 			else
 /*N*/ 				pCMS->aRealHeight.X() = 0;
-/*N*/ 			ASSERT( nPorHeight, "GetCharRect: Missing Portion-Height" );
+/*N*/ 			OSL_ENSURE( nPorHeight, "GetCharRect: Missing Portion-Height" );
 /*N*/ 			if ( nTmpHeight > nPorHeight )
 /*N*/ 				pCMS->aRealHeight.Y() = nPorHeight;
 /*N*/ 			else
@@ -707,8 +707,8 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*?*/         xub_StrLen nLineOfst = pCMS->pSpecialPos->nLineOfst;
 /*?*/         BYTE nExtendRange = pCMS->pSpecialPos->nExtendRange;
 /*?*/ 
-/*?*/         ASSERT( ! nLineOfst || SP_EXTEND_RANGE_BEFORE != nExtendRange,
-/*?*/                 "LineOffset AND Number Portion?" )
+/*?*/         OSL_ENSURE( ! nLineOfst || SP_EXTEND_RANGE_BEFORE != nExtendRange,
+/*?*/                 "LineOffset AND Number Portion?" );
 /*?*/ 
 /*?*/         // portions which are behind the string
 /*?*/         if ( SP_EXTEND_RANGE_BEHIND == nExtendRange )
@@ -871,7 +871,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/ 
 /*N*/     KSHORT nWidth30;
 /*N*/     if ( pPor->IsPostItsPortion() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/         nWidth30 = 30 + pPor->GetViewWidth( GetInfo() ) / 2;
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/     else
 /*N*/         nWidth30 = ! nWidth && pPor->GetLen() && pPor->InToxRefOrFldGrp() ?
 /*N*/                      30 :
@@ -916,7 +916,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*?*/ 		}
 /*?*/ 
 /*?*/         if ( pPor->IsPostItsPortion() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/             nWidth30 = 30 + pPor->GetViewWidth( GetInfo() ) / 2;
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*?*/         else
 /*?*/             nWidth30 = ! nWidth && pPor->GetLen() && pPor->InToxRefOrFldGrp() ?
 /*?*/                          30 :
@@ -1045,7 +1045,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/ 	{
 /*N*/ 		if( pPor->IsMultiPortion() )
 /*N*/ 		{
-                DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/             // In a multi-portion we use GetCrsrOfst()-function recursively
+                DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 		if( pPor->InTxtGrp() )
 /*N*/ 		{
@@ -1065,7 +1065,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/ 						((SwDropPortion*)pPor)->GetFnt() : NULL );
 /*N*/ 
 /*N*/                 SwParaPortion* pPara = (SwParaPortion*)GetInfo().GetParaPortion();
-/*N*/                 ASSERT( pPara, "No paragraph!" );
+/*N*/                 OSL_ENSURE( pPara, "No paragraph!" );
 /*N*/ 
 /*N*/                 SwDrawTextInfo aDrawInf( aSizeInf.GetVsh(),
 /*N*/                                          *aSizeInf.GetOut(),
@@ -1103,7 +1103,7 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/ 		{
 /*N*/ 			if( nChgNode && pPos && pPor->IsFlyCntPortion()
 /*N*/ 				&& !( (SwFlyCntPortion*)pPor )->IsDraw() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*N*/ 			{
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 		}
 /*N*/ 	}
 /*N*/ 	nOffset = nCurrStart + nLength;
