@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,100 +31,42 @@
 #pragma hdrstop
 #endif
 
-#ifndef _COM_SUN_STAR_TEXT_SECTIONFILELINK_HPP_
 #include <com/sun/star/text/SectionFileLink.hpp>
-#endif
 
 #include <cmdid.h>
-#ifndef _HINTIDS_HXX
 #include <hintids.hxx>
-#endif
-#ifndef SVTOOLS_URIHELPER_HXX
 #include <bf_svtools/urihelper.hxx>
-#endif
-#ifndef _SVX_BRSHITEM_HXX //autogen
 #include <bf_svx/brshitem.hxx>
-#endif
-#ifndef _SVX_XMLCNITEM_HXX
 #include <bf_svx/xmlcnitm.hxx>
-#endif
-#ifndef _LINKMGR_HXX
 #include <bf_so3/linkmgr.hxx>
-#endif
-#ifndef _LNKBASE_HXX
 #include <bf_so3/lnkbase.hxx>
-#endif
-#ifndef _VOS_MUTEX_HXX_ //autogen
-#include <vos/mutex.hxx>
-#endif
-#ifndef _SV_SVAPP_HXX //autogen
+#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
-#endif
-#ifndef _FMTCLDS_HXX //autogen
 #include <fmtclds.hxx>
-#endif
 
-#ifndef _ERRHDL_HXX
-#include <errhdl.hxx>
-#endif
+#include <osl/diagnose.h>
 
-#ifndef _UNOOBJ_HXX
 #include <unoobj.hxx>
-#endif
-#ifndef _UNOREDLINE_HXX
 #include <unoredline.hxx>
-#endif
-#ifndef _REDLINE_HXX
 #include <redline.hxx>
-#endif
-#ifndef _UNOMAP_HXX
 #include <unomap.hxx>
-#endif
-#ifndef _UNOCRSR_HXX
 #include <unocrsr.hxx>
-#endif
-#ifndef _SECTION_HXX //autogen
 #include <section.hxx>
-#endif
 
-#ifndef _HORIORNT_HXX
 #include <horiornt.hxx>
-#endif
 
-#ifndef _DOC_HXX //autogen
 #include <doc.hxx>
-#endif
-#ifndef _DOCARY_HXX
 #include <docary.hxx>
-#endif
-#ifndef _HINTS_HXX //autogen
 #include <hints.hxx>
-#endif
-#ifndef _TOX_HXX
 #include <tox.hxx>
-#endif
-#ifndef _UNOIDX_HXX
 #include <unoidx.hxx>
-#endif
-#ifndef _DOCTXM_HXX
 #include <doctxm.hxx>
-#endif
-#ifndef _FMTFTNTX_HXX
 #include <fmtftntx.hxx>
-#endif
-#ifndef _FMTCLBL_HXX
 #include <fmtclbl.hxx>
-#endif
-#ifndef _COM_SUN_STAR_BEANS_PROPERTYATTRIBUTE_HPPP_
 #include <com/sun/star/beans/PropertyAttribute.hpp>
-#endif
-#ifndef _SVX_FRMDIRITEM_HXX
 #include <bf_svx/frmdiritem.hxx>
-#endif
 /* #109700# */
-#ifndef _SVX_LRSPITEM_HXX
 #include <bf_svx/lrspitem.hxx>
-#endif
 #include "bf_so3/staticbaseurl.hxx"
 namespace binfilter {
 
@@ -133,7 +76,8 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::text;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::beans;
-using namespace ::rtl;
+
+using rtl::OUString;
 
 /******************************************************************
  *
@@ -163,10 +107,6 @@ struct SwTextSectionProperties_Impl
     sal_Bool    bUpdateType;
 
     SwTextSectionProperties_Impl() :
-        bDDE(0),
-        bHidden(0),
-        bProtect(0),
-        bCondHidden(0),
         pColItem(0),
         pBrushItem(0),
         pFtnItem(0),
@@ -175,6 +115,10 @@ struct SwTextSectionProperties_Impl
         pNoBalanceItem(0),
         pFrameDirItem(0),
         pLRSpaceItem(0), // #109700#
+        bDDE(0),
+        bHidden(0),
+        bCondHidden(0),
+        bProtect(0),
         bUpdateType(sal_True){}
 
     ~SwTextSectionProperties_Impl()
@@ -189,9 +133,7 @@ struct SwTextSectionProperties_Impl
         delete pLRSpaceItem; // #109700#
     }
 };
-/* -----------------------------11.07.00 12:10--------------------------------
 
- ---------------------------------------------------------------------------*/
 SwXTextSection* SwXTextSection::GetImplementation(Reference< XInterface> xRef )
 {
     uno::Reference<lang::XUnoTunnel> xTunnel( xRef, uno::UNO_QUERY);
@@ -200,17 +142,13 @@ SwXTextSection* SwXTextSection::GetImplementation(Reference< XInterface> xRef )
     return 0;
 }
 
-/* -----------------------------13.03.00 12:15--------------------------------
 
- ---------------------------------------------------------------------------*/
 const uno::Sequence< sal_Int8 > & SwXTextSection::getUnoTunnelId()
 {
     static uno::Sequence< sal_Int8 > aSeq = ::binfilter::CreateUnoTunnelId();
     return aSeq;
 }
-/* -----------------------------10.03.00 18:04--------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Int64 SAL_CALL SwXTextSection::getSomething( const uno::Sequence< sal_Int8 >& rId )
     throw(uno::RuntimeException)
 {
@@ -222,9 +160,7 @@ sal_Int64 SAL_CALL SwXTextSection::getSomething( const uno::Sequence< sal_Int8 >
     }
     return 0;
 }
-/*-- 10.12.98 14:47:05---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXTextSection::SwXTextSection(SwSectionFmt* pFmt, BOOL bIndexHeader) :
         SwClient(pFmt),
         aLstnrCntnr( (text::XTextContent*)this),
@@ -236,19 +172,15 @@ SwXTextSection::SwXTextSection(SwSectionFmt* pFmt, BOOL bIndexHeader) :
 {
 
 }
-/*-- 10.12.98 14:47:07---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXTextSection::~SwXTextSection()
 {
     delete pProps;
 }
-/*-- 10.12.98 14:47:08---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextSection >  SwXTextSection::getParentSection(void) throw( uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Reference< text::XTextSection >  aRef;
     SwSectionFmt*  pSectFmt = GetFmt();
     if(pSectFmt)
@@ -268,13 +200,11 @@ uno::Reference< text::XTextSection >  SwXTextSection::getParentSection(void) thr
         throw uno::RuntimeException();
     return aRef;
 }
-/*-- 10.12.98 14:47:08---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Sequence< uno::Reference< text::XTextSection >  > SwXTextSection::getChildSections(void)
     throw( uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Sequence<uno::Reference< text::XTextSection > > aSeq;
     SwSectionFmt*  pSectFmt = GetFmt();
     if(pSectFmt)
@@ -297,9 +227,7 @@ uno::Sequence< uno::Reference< text::XTextSection >  > SwXTextSection::getChildS
     return aSeq;
 
 }
-/* -----------------18.02.99 13:31-------------------
- *
- * --------------------------------------------------*/
+
 void SwXTextSection::attachToRange(const uno::Reference< text::XTextRange > & xTextRange)
     throw( lang::IllegalArgumentException, uno::RuntimeException )
 {
@@ -325,8 +253,6 @@ void SwXTextSection::attachToRange(const uno::Reference< text::XTextRange > & xT
         SwXTextRange::XTextRangeToSwPaM(aPam, xTextRange);
         UnoActionContext aCont(pDoc);
 
-        sal_Bool bRet = sal_False;
-
         SwSection* pRet = 0;
         if(!m_sName.Len())
             m_sName =  C2S("TextSection");
@@ -430,22 +356,18 @@ void SwXTextSection::attachToRange(const uno::Reference< text::XTextRange > & xT
     else
         throw lang::IllegalArgumentException();
 }
-/*-- 10.12.98 14:47:09---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextSection::attach(const uno::Reference< text::XTextRange > & xTextRange)
                     throw( lang::IllegalArgumentException, uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     attachToRange( xTextRange );
 }
 
-/*-- 10.12.98 14:47:09---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextRange >  SwXTextSection::getAnchor(void) throw( uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Reference< text::XTextRange >  xRet;
     SwSectionFmt*  pSectFmt = GetFmt();
     if(pSectFmt)
@@ -468,46 +390,36 @@ uno::Reference< text::XTextRange >  SwXTextSection::getAnchor(void) throw( uno::
     }
     return xRet;
 }
-/*-- 10.12.98 14:47:09---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextSection::dispose(void) throw( uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     SwSectionFmt*  pSectFmt = GetFmt();
     if(pSectFmt)
         pSectFmt->GetDoc()->DelSectionFmt( pSectFmt );
     else
         throw uno::RuntimeException();
 }
-/*-- 10.12.98 14:47:10---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextSection::addEventListener(const uno::Reference< lang::XEventListener > & aListener) throw( uno::RuntimeException )
 {
     if(!GetRegisteredIn())
         throw uno::RuntimeException();
     aLstnrCntnr.AddListener(aListener);
 }
-/*-- 10.12.98 14:47:10---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextSection::removeEventListener(const uno::Reference< lang::XEventListener > & aListener) throw( uno::RuntimeException )
 {
     if(!GetRegisteredIn() || !aLstnrCntnr.RemoveListener(aListener))
         throw uno::RuntimeException();
 }
-/*-- 10.12.98 14:47:11---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< beans::XPropertySetInfo >  SwXTextSection::getPropertySetInfo(void) throw( uno::RuntimeException )
 {
     static uno::Reference< beans::XPropertySetInfo >  aRef = aPropSet.getPropertySetInfo();
     return aRef;
 }
-/* -----------------------------12.02.01 10:29--------------------------------
 
- ---------------------------------------------------------------------------*/
 struct SwSectItemSet_Impl
 {
 
@@ -517,16 +429,14 @@ struct SwSectItemSet_Impl
     ~SwSectItemSet_Impl()
         {delete pItemSet;}
 };
-/* -----------------------------12.02.01 10:45--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwXTextSection::setPropertyValues(
     const Sequence< ::rtl::OUString >& rPropertyNames,
     const Sequence< Any >& rValues )
         throw(PropertyVetoException, lang::IllegalArgumentException,
                         lang::WrappedTargetException, RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     SwSectionFmt*   pFmt = GetFmt();
     if(rPropertyNames.getLength() != rValues.getLength())
         throw IllegalArgumentException();
@@ -541,7 +451,7 @@ void SwXTextSection::setPropertyValues(
         SwSectItemSet_Impl aItemSet;
 
         sal_Bool bLinkModeChanged = sal_False;
-        sal_Bool bLinkMode;
+        sal_Bool bLinkMode = sal_False;
         for(sal_Int16 nProperty = 0; nProperty < rPropertyNames.getLength(); nProperty++)
         {
             const SfxItemPropertyMap*   pMap = SfxItemPropertyMap::GetByName(
@@ -784,7 +694,6 @@ void SwXTextSection::setPropertyValues(
             {
                 if(rFmts[i]->GetSection()->GetName() == pSect->GetName())
                 {
-                    // --> OD 2006-07-14 #b6448029#
                     // always prevent update of an existing link in the section
                     pDoc->ChgSection( i, aSection, aItemSet.pItemSet, sal_True );
                     // <--
@@ -794,15 +703,15 @@ void SwXTextSection::setPropertyValues(
                         UnoActionRemoveContext aRemoveContext( pDoc );
                     }
 
-                    SwSection* pSect = pFmt->GetSection();
-                    if( bLinkModeChanged && pSect->GetType() == DDE_LINK_SECTION)
+                    SwSection* pLclSect = pFmt->GetSection();
+                    if( bLinkModeChanged && pLclSect->GetType() == DDE_LINK_SECTION)
                     {
                         // set update type; needs an established link
-                        if(!pSect->IsConnected())
+                        if(!pLclSect->IsConnected())
                         {
-                            pSect->CreateLink(CREATE_CONNECT);
+                            pLclSect->CreateLink(CREATE_CONNECT);
                         }
-                        pSect->SetUpdateType(bLinkMode ? ::binfilter::LINKUPDATE_ALWAYS
+                        pLclSect->SetUpdateType(bLinkMode ? ::binfilter::LINKUPDATE_ALWAYS
                                                 : ::binfilter::LINKUPDATE_ONCALL);
                     }
                     // section found and processed: break from loop
@@ -815,30 +724,26 @@ void SwXTextSection::setPropertyValues(
         throw uno::RuntimeException();
 
 }
-/*-- 10.12.98 14:47:11---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextSection::setPropertyValue(
     const OUString& rPropertyName, const uno::Any& aValue)
     throw( beans::UnknownPropertyException, beans::PropertyVetoException,
         lang::IllegalArgumentException,     lang::WrappedTargetException,
         uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     Sequence< ::rtl::OUString > aPropertyNames(1);
     aPropertyNames.getArray()[0] = rPropertyName;
     Sequence< Any > aValues(1);
     aValues.getArray()[0] = aValue;
     setPropertyValues(aPropertyNames, aValues);
 }
-/* -----------------------------12.02.01 10:43--------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence< Any > SwXTextSection::getPropertyValues(
     const Sequence< ::rtl::OUString >& rPropertyNames )
         throw(RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     Sequence< Any > aRet(rPropertyNames.getLength());
     Any* pRet = aRet.getArray();
     SwSectionFmt*   pFmt = GetFmt();
@@ -1077,93 +982,77 @@ Sequence< Any > SwXTextSection::getPropertyValues(
         throw uno::RuntimeException();
     return aRet;
 }
-/*-- 10.12.98 14:47:12---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Any SwXTextSection::getPropertyValue(const OUString& rPropertyName)
     throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     Sequence< ::rtl::OUString > aPropertyNames(1);
     aPropertyNames.getArray()[0] = rPropertyName;
     return getPropertyValues(aPropertyNames).getConstArray()[0];
 }
-/* -----------------------------12.02.01 10:30--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwXTextSection::addPropertiesChangeListener(
-    const Sequence< ::rtl::OUString >& aPropertyNames,
-    const Reference< XPropertiesChangeListener >& xListener ) throw(RuntimeException)
+    const Sequence< ::rtl::OUString >& /*aPropertyNames*/,
+    const Reference< XPropertiesChangeListener >& /*xListener*/ ) throw(RuntimeException)
 {
     DBG_WARNING("not implemented");
 }
-/* -----------------------------12.02.01 10:30--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwXTextSection::removePropertiesChangeListener(
-    const Reference< XPropertiesChangeListener >& xListener )
+    const Reference< XPropertiesChangeListener >& /*xListener*/ )
         throw(RuntimeException)
 {
     DBG_WARNING("not implemented");
 }
-/* -----------------------------12.02.01 10:30--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwXTextSection::firePropertiesChangeEvent(
-    const Sequence< ::rtl::OUString >& aPropertyNames,
-    const Reference< XPropertiesChangeListener >& xListener )
+    const Sequence< ::rtl::OUString >& /*aPropertyNames*/,
+    const Reference< XPropertiesChangeListener >& /*xListener*/ )
         throw(RuntimeException)
 {
     DBG_WARNING("not implemented");
 }
-/*-- 10.12.98 14:47:13---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXTextSection::addPropertyChangeListener(const OUString& PropertyName, const uno::Reference< beans::XPropertyChangeListener > & aListener) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextSection::addPropertyChangeListener(const OUString& /*PropertyName*/, const uno::Reference< beans::XPropertyChangeListener > & /*aListener*/) throw( 
+beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     DBG_WARNING("not implemented");
 }
-/*-- 10.12.98 14:47:13---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXTextSection::removePropertyChangeListener(const OUString& PropertyName, const uno::Reference< beans::XPropertyChangeListener > & aListener) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextSection::removePropertyChangeListener(const OUString& /*PropertyName*/, const uno::Reference< beans::XPropertyChangeListener > & /*aListener*/) throw( 
+beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     DBG_WARNING("not implemented");
 }
-/*-- 10.12.98 14:47:14---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXTextSection::addVetoableChangeListener(const OUString& PropertyName, const uno::Reference< beans::XVetoableChangeListener > & aListener) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextSection::addVetoableChangeListener(const OUString& /*PropertyName*/, const uno::Reference< beans::XVetoableChangeListener > & /*aListener*/) throw( 
+beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     DBG_WARNING("not implemented");
 }
-/*-- 10.12.98 14:47:14---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXTextSection::removeVetoableChangeListener(const OUString& PropertyName, const uno::Reference< beans::XVetoableChangeListener > & aListener) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextSection::removeVetoableChangeListener(const OUString& /*PropertyName*/, const uno::Reference< beans::XVetoableChangeListener > & /*aListener*/) throw( 
+beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     DBG_WARNING("not implemented");
 }
 
-/*-- 08.11.00 10:47:55---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 PropertyState SwXTextSection::getPropertyState( const OUString& rPropertyName )
     throw(UnknownPropertyException, RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     Sequence< OUString > aNames(1);
     aNames.getArray()[0] = rPropertyName;
     return getPropertyStates(aNames).getConstArray()[0];
 }
-/*-- 08.11.00 10:47:55---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Sequence< PropertyState > SwXTextSection::getPropertyStates(
     const Sequence< OUString >& rPropertyNames )
         throw(UnknownPropertyException, RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     Sequence< PropertyState > aStates(rPropertyNames.getLength());
     SwSectionFmt*   pFmt = GetFmt();
     if(pFmt||m_bIsDescriptor)
@@ -1199,7 +1088,6 @@ Sequence< PropertyState > SwXTextSection::getPropertyStates(
                         pStates[i] = aPropSet.getPropertyState(pNames[i], pFmt->GetAttrSet());
                     else
                     {
-                        const SfxPoolItem* pQueryItem = 0;
                         if(RES_COL == pMap->nWID)
                         {
                             if(!pProps->pColItem)
@@ -1222,13 +1110,11 @@ Sequence< PropertyState > SwXTextSection::getPropertyStates(
         throw RuntimeException();
     return aStates;
 }
-/*-- 08.11.00 10:47:55---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextSection::setPropertyToDefault( const OUString& rPropertyName )
     throw(UnknownPropertyException, RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     SwSectionFmt*   pFmt = GetFmt();
     if(pFmt||m_bIsDescriptor)
     {
@@ -1311,7 +1197,6 @@ void SwXTextSection::setPropertyToDefault( const OUString& rPropertyName )
             {
                 if(rFmts[i]->GetSection()->GetName() == pSect->GetName())
                 {
-                    // --> OD 2006-07-14 #b6448029#
                     // always prevent update of an existing link in the section
                     pDoc->ChgSection( i, aSection, pNewAttrSet, sal_True );
                     // <--
@@ -1330,13 +1215,11 @@ void SwXTextSection::setPropertyToDefault( const OUString& rPropertyName )
     else
         throw RuntimeException();
 }
-/*-- 08.11.00 10:47:56---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Any SwXTextSection::getPropertyDefault( const OUString& rPropertyName )
     throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Any aRet;
     SwSectionFmt*   pFmt = GetFmt();
     const SfxItemPropertyMap*   pMap = SfxItemPropertyMap::GetByName(
@@ -1386,12 +1269,10 @@ Any SwXTextSection::getPropertyDefault( const OUString& rPropertyName )
     }
     return aRet;
 }
-/*-- 10.12.98 14:47:15---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 OUString SwXTextSection::getName(void) throw( uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     String sRet;
     const SwSectionFmt* pFmt = GetFmt();
     if(pFmt)
@@ -1402,12 +1283,10 @@ OUString SwXTextSection::getName(void) throw( uno::RuntimeException )
         throw uno::RuntimeException();
     return sRet;
 }
-/*-- 10.12.98 14:47:16---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextSection::setName(const OUString& rName) throw( uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     SwSectionFmt*   pFmt = GetFmt();
     if(pFmt)
     {
@@ -1443,25 +1322,19 @@ void SwXTextSection::setName(const OUString& rName) throw( uno::RuntimeException
     else
         throw uno::RuntimeException();
 }
-/* -----------------02.11.99 11:30-------------------
 
- --------------------------------------------------*/
 OUString SwXTextSection::getImplementationName(void) throw( uno::RuntimeException )
 {
     return C2U("SwXTextSection");
 }
-/* -----------------02.11.99 11:30-------------------
 
- --------------------------------------------------*/
 sal_Bool SwXTextSection::supportsService(const OUString& rServiceName) throw( uno::RuntimeException )
 {
     return !rServiceName.compareToAscii("com.sun.star.text.TextSection") ||
                 !rServiceName.compareToAscii("com.sun.star.document.LinkTarget") ||
                     !rServiceName.compareToAscii("com.sun.star.text.TextContent");
 }
-/* -----------------02.11.99 11:30-------------------
 
- --------------------------------------------------*/
 uno::Sequence< OUString > SwXTextSection::getSupportedServiceNames(void) throw( uno::RuntimeException )
 {
     uno::Sequence< OUString > aRet(3);
@@ -1472,9 +1345,7 @@ uno::Sequence< OUString > SwXTextSection::getSupportedServiceNames(void) throw(
     return aRet;
 }
 
-/*-- 10.12.98 14:42:52---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextSection::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew)
 {
     if(pOld && pOld->Which() == RES_REMOVE_UNO_OBJECT &&
@@ -1487,3 +1358,5 @@ void SwXTextSection::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew)
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
