@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -45,8 +46,6 @@
 
 #include "swfexporter.hxx"
 
-//#include <stdlib.h>
-//#include <windows.h>
 #include <string.h>
 
 using namespace ::com::sun::star::uno;
@@ -77,7 +76,7 @@ public:
     OslOutputStreamWrapper(const OUString& sFileName) : mrFile(sFileName) 
     { 
         osl_removeFile(sFileName.pData);
-        mrFile.open(OpenFlag_Create|OpenFlag_Write);
+        mrFile.open( osl_File_OpenFlag_Create|osl_File_OpenFlag_Write );
     }
 
     // stario::XOutputStream
@@ -156,8 +155,6 @@ class FlashExportFilter : public cppu::WeakImplHelper4
     Reference< XMultiServiceFactory > mxMSF;
     Reference< XStatusIndicator> mxStatusIndicator;
 
-    osl::File* mpFile;
-
 public:
     FlashExportFilter( const Reference< XMultiServiceFactory > &rxMSF);
 
@@ -277,7 +274,7 @@ sal_Bool FlashExportFilter::ExportAsMultipleFiles(const Sequence< PropertyValue
     if(!xDrawPages.is())
         return sal_False;
 
-    Reference< XDesktop > rDesktop( mxMSF->createInstance(OUString::createFromAscii("com.sun.star.frame.Desktop")), UNO_QUERY);
+    Reference< XDesktop > rDesktop( mxMSF->createInstance(OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.frame.Desktop" ))), UNO_QUERY);
     if (!rDesktop.is())
         return sal_False;
 
@@ -336,6 +333,9 @@ sal_Bool FlashExportFilter::ExportAsMultipleFiles(const Sequence< PropertyValue
         err = osl_writeFile(xBackgroundConfig, "slides=", strlen("slides="), &bytesWritten);
     }
 
+    // TODO: check for errors
+    (void) err;
+
     FlashExporter aFlashExporter( mxMSF, findPropertyValue<sal_Int32>(aFilterData, "CompressMode", 75), 
                                          findPropertyValue<sal_Bool>(aFilterData, "ExportOLEAsJPEG", false));
 
@@ -524,3 +524,5 @@ sal_Bool SAL_CALL FlashExportFilter::supportsService( const OUString& rServiceNa
 // -----------------------------------------------------------------------------
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
