@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -142,7 +143,7 @@ void Writer::Impl_addPolygon( BitStream& rBits, const Polygon& rPoly, sal_Bool b
 
     Impl_addShapeRecordChange( rBits, _Int16(aLastPoint.X()),_Int16(aLastPoint.Y()), bFilled );
 
-    USHORT i = 0, nSize = rPoly.GetSize();
+    sal_uInt16 i = 0, nSize = rPoly.GetSize();
 
     double d = 16.0f;
 
@@ -539,7 +540,7 @@ void Writer::Impl_writeText( const Point& rPos, const String& rText, const sal_I
     {
         // todo: optimize me as this will generate a huge amount of duplicate polygons
         PolyPolygon aPolyPoygon;
-        mpVDev->GetTextOutline( aPolyPoygon, rText, 0, 0, (USHORT)nLen, TRUE, nWidth, pDXArray );
+        mpVDev->GetTextOutline( aPolyPoygon, rText, 0, 0, (sal_uInt16)nLen, sal_True, nWidth, pDXArray );
         aPolyPoygon.Translate( rPos );
         Impl_writePolyPolygon( aPolyPoygon, sal_True, aTextColor, aTextColor );
     }
@@ -565,7 +566,7 @@ void Writer::Impl_writeText( const Point& rPos, const String& rText, const sal_I
 
         if( nLen > 1 )
         {
-            aNormSize.Width() = pDX[ nLen - 2 ] + mpVDev->GetTextWidth( rText.GetChar(  (USHORT) nLen - 1 ) );
+            aNormSize.Width() = pDX[ nLen - 2 ] + mpVDev->GetTextWidth( rText.GetChar(  (sal_uInt16) nLen - 1 ) );
 
             if( nWidth && aNormSize.Width() && ( nWidth != aNormSize.Width() ) )
             {
@@ -611,22 +612,6 @@ void Writer::Impl_writeText( const Point& rPos, const String& rText, const sal_I
 
         // write text element
 
-/* test code to create a bound rect, not realy working for rotated text
-            Size		aTextSize( map( Size( mpVDev->GetTextWidth( rText ), mpVDev->GetTextHeight() ) ) );
-            Point		aMetricPoint( map( Point( aMetric.GetLeading(), aMetric.GetAscent() )  ) );
-
-            Point		aTmpPoint( map( Point( - aMetric.GetLeading(), - aMetric.GetAscent() )  ) ); ;
-            Rectangle	aTmpRectangle(aTmpPoint, aTextSize );
-            Polygon 	aPoly( aTmpRectangle );
-
-            aPoly.Rotate( aTmpPoint, (USHORT) nOrientation );
-
-            Rectangle   aTextBoundRect( aPoly.GetBoundRect() );
-
-            aPoly.Move( aPt.X(), aPt.Y() - map( Size( 0, aMetric.GetDescent() ) ).Height() );
-
-*/
-
 #if	0 // makes the calculated bound rect visible for debuging
 {
         Polygon aTmpPoly( aPoly );
@@ -831,7 +816,7 @@ void getBitmapData( const BitmapEx& aBmpEx, sal_uInt8*& tgadata, sal_uInt8*& tga
 // -----------------------------------------------------------------------------
 sal_uInt16 Writer::defineBitmap( const BitmapEx &bmpSource, sal_Int32 nJPEGQualityLevel )
 {
-    ULONG bmpChecksum = bmpSource.GetChecksum();
+    sal_uLong bmpChecksum = bmpSource.GetChecksum();
 
     ChecksumCache::iterator it = mBitmapCache.find(bmpChecksum);
 
@@ -898,15 +883,6 @@ sal_uInt16 Writer::defineBitmap( const BitmapEx &bmpSource, sal_Int32 nJPEGQuali
         aFilterData[0].Value <<= nJPEGQualityLevel;
     }
 
-#if 0
-    // Debug code to see what we export to swf
-    {
-        SvFileStream aDstStm( String( RTL_CONSTASCII_USTRINGPARAM("e:\\test.jpg") ), STREAM_READ | STREAM_WRITE | STREAM_TRUNC );
-        aFilter.ExportGraphic( aGraphic, String(), aDstStm,
-                                aFilter.GetExportFormatNumberForShortName( OUString( RTL_CONSTASCII_USTRINGPARAM( JPG_SHORTNAME ) ) ), &aFilterData );
-    }
-#endif
-
     if( aFilter.ExportGraphic( aGraphic, String(), aDstStm,
                                 aFilter.GetExportFormatNumberForShortName( OUString( RTL_CONSTASCII_USTRINGPARAM( JPG_SHORTNAME ) ) ), &aFilterData ) == ERRCODE_NONE )
     {
@@ -1068,7 +1044,7 @@ void Writer::Impl_writeJPEG(sal_uInt16 nBitmapId, const sal_uInt8* pJpgData, sal
 #ifdef DBG_UTIL
         if (0xFF != *pJpgSearch)
         {
-            DBG_ERROR( "Expected JPEG marker." ); ((void)0);
+            OSL_FAIL( "Expected JPEG marker." ); ((void)0);
         }
 #endif
 
@@ -1138,7 +1114,7 @@ void Writer::Impl_writeJPEG(sal_uInt16 nBitmapId, const sal_uInt8* pJpgData, sal
             break;
 
         default:
-            DBG_ERROR( "JPEG marker I didn't handle!" );
+            OSL_FAIL( "JPEG marker I didn't handle!" );
 
         }
     }
@@ -1259,7 +1235,7 @@ bool Writer::Impl_writeStroke( SvtGraphicStroke& rStroke )
     Color aColor( mpVDev->GetLineColor() );
 
     if( 0.0 != rStroke.getTransparency() )
-        aColor.SetTransparency( sal::static_int_cast<UINT8>( MinMax( (long int)( rStroke.getTransparency() * 0xff ), 0, 0xff ) ) );
+        aColor.SetTransparency( sal::static_int_cast<sal_uInt8>( MinMax( (long int)( rStroke.getTransparency() * 0xff ), 0, 0xff ) ) );
 
     sal_uInt16 nShapeId = defineShape( aPolyPolygon, sal::static_int_cast<sal_uInt16>( mapRelative( (sal_Int32)( rStroke.getStrokeWidth() ) ) ), aColor );
     maShapeIds.push_back( nShapeId );
@@ -1289,7 +1265,7 @@ bool Writer::Impl_writeFilling( SvtGraphicFill& rFilling )
             Color aColor( rFilling.getFillColor() );
 
             if( 0.0 != rFilling.getTransparency() )
-                aColor.SetTransparency( sal::static_int_cast<UINT8>( MinMax( (long int)( rFilling.getTransparency() * 0xff ) , 0, 0xff ) ) );
+                aColor.SetTransparency( sal::static_int_cast<sal_uInt8>( MinMax( (long int)( rFilling.getTransparency() * 0xff ) , 0, 0xff ) ) );
 
             FillStyle aFillStyle( aColor );
 
@@ -1328,12 +1304,10 @@ bool Writer::Impl_writeFilling( SvtGraphicFill& rFilling )
             aMatrix.set(2, 2, 1.0); 
 
             // scale bitmap
-            Rectangle originalPixelRect = Rectangle(Point(), aGraphic.GetBitmapEx().GetSizePixel());
-
             double XScale = (double)aNewRect.GetWidth()/aOldRect.GetWidth();
             double YScale = (double)aNewRect.GetHeight()/aOldRect.GetHeight();
 
-             aMatrix.scale( XScale, YScale );
+            aMatrix.scale( XScale, YScale );
 
             FillStyle aFillStyle( nBitmapId, !rFilling.IsTiling(), aMatrix );
 
@@ -1440,10 +1414,10 @@ void Writer::Impl_writeActions( const GDIMetaFile& rMtf )
 {
     Rectangle clipRect;
     int bMap = 0;
-    for( ULONG i = 0, nCount = rMtf.GetActionCount(); i < nCount; i++ )
+    for( sal_uLong i = 0, nCount = rMtf.GetActionCount(); i < nCount; i++ )
     {
         const MetaAction*	pAction = rMtf.GetAction( i );
-        const USHORT		nType = pAction->GetType();
+        const sal_uInt16		nType = pAction->GetType();
 
         switch( nType )
         {
@@ -1661,7 +1635,7 @@ void Writer::Impl_writeActions( const GDIMetaFile& rMtf )
                 const GDIMetaFile		aGDIMetaFile( pA->GetSubstitute() );
                 sal_Bool				bFound = sal_False;
 
-                for( ULONG j = 0, nC = aGDIMetaFile.GetActionCount(); ( j < nC ) && !bFound; j++ )
+                for( sal_uLong j = 0, nC = aGDIMetaFile.GetActionCount(); ( j < nC ) && !bFound; j++ )
                 {
                     const MetaAction* pSubstAct = aGDIMetaFile.GetAction( j );
                     
@@ -1680,7 +1654,7 @@ void Writer::Impl_writeActions( const GDIMetaFile& rMtf )
             case( META_COMMENT_ACTION ):
             {
                 const MetaCommentAction*	pA = (const MetaCommentAction*) pAction;
-                const BYTE* 				pData = pA->GetData();
+                const sal_uInt8* 				pData = pA->GetData();
                 String						aSkipComment;
 
                 if( pA->GetComment().CompareIgnoreCaseToAscii( "XGRAD_SEQ_BEGIN" ) == COMPARE_EQUAL )
@@ -1886,20 +1860,11 @@ void Writer::Impl_writeActions( const GDIMetaFile& rMtf )
             case( META_MOVECLIPREGION_ACTION ):
             {
                 ( (MetaAction*) pAction )->Execute( mpVDev );
-//				mbClipAttrChanged = sal_True;
             }
             break;
 
             case( META_MAPMODE_ACTION ):
             {
-//				const MetaMapModeAction *pA = (const MetaMapModeAction*) pAction;
-//				MapMode mm = pA->GetMapMode();
-//				MapUnit mu = mm.GetMapUnit();
-//
-//				Point pt = mm.GetOrigin();
-//				Fraction fx = mm.GetScaleX();
-//				Fraction fy = mm.GetScaleY();
-
                 bMap++;
             }
             case( META_REFPOINT_ACTION ):
@@ -1930,7 +1895,6 @@ void Writer::Impl_writeActions( const GDIMetaFile& rMtf )
             break;
 
             default:
-                //DBG_ERROR( "FlashActionWriter::ImplWriteActions: unsupported MetaAction #" );
             break;
         }
     }
@@ -2120,7 +2084,9 @@ Reference < XBreakIterator > Writer::Impl_GetBreakIterator()
     if ( !mxBreakIterator.is() )
     {
         Reference< XMultiServiceFactory > xMSF( ::comphelper::getProcessServiceFactory() );
-        mxBreakIterator.set( xMSF->createInstance( OUString::createFromAscii( "com.sun.star.i18n.BreakIterator" ) ), UNO_QUERY );
+        mxBreakIterator.set( xMSF->createInstance( OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.i18n.BreakIterator" )) ), UNO_QUERY );
     }
     return mxBreakIterator;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
