@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -46,8 +47,6 @@
 #include "oox/ppt/slidefragmenthandler.hxx"
 #include "oox/ppt/layoutfragmenthandler.hxx"
 #include "oox/ppt/pptimport.hxx"
-#include "oox/core/namespaces.hxx"
-#include "tokens.hxx"
 
 using rtl::OUString;
 using namespace ::com::sun::star;
@@ -130,7 +129,7 @@ void ResolveTextFields( XmlFilterBase& rFilter )
                             aURL = CREATE_OUSTRING( "#" ).concat( xNamed->getName() );
                             xPropSet->setPropertyValue( sURL, Any( aURL ) );
                             Reference< text::XTextContent > xContent( rTextField.xTextField, UNO_QUERY);
-                            Reference< text::XTextRange > xTextRange( rTextField.xTextCursor, UNO_QUERY );						
+                            Reference< text::XTextRange > xTextRange( rTextField.xTextCursor, UNO_QUERY );
                             rTextField.xText->insertTextContent( xTextRange, xContent, sal_True );
                         }
                         catch( uno::Exception& )
@@ -138,7 +137,7 @@ void ResolveTextFields( XmlFilterBase& rFilter )
                         }
                     }
                 }
-            }		
+            }
         }
     }
 }
@@ -182,12 +181,12 @@ void PresentationFragmentHandler::endDocument() throw (SAXException, RuntimeExce
                 FragmentHandlerRef xSlideFragmentHandler( new SlideFragmentHandler( rFilter, aSlideFragmentPath, pSlidePersistPtr, Slide ) );
 
                 // importing the corresponding masterpage/layout
-                OUString aLayoutFragmentPath = xSlideFragmentHandler->getFragmentPathFromFirstType( CREATE_OFFICEDOC_RELATIONSTYPE( "slideLayout" ) );
+                OUString aLayoutFragmentPath = xSlideFragmentHandler->getFragmentPathFromFirstType( CREATE_OFFICEDOC_RELATION_TYPE( "slideLayout" ) );
                 if ( aLayoutFragmentPath.getLength() > 0 )
                 {
                     // importing layout
                     RelationsRef xLayoutRelations = rFilter.importRelations( aLayoutFragmentPath );
-                    OUString aMasterFragmentPath = xLayoutRelations->getFragmentPathFromFirstType( CREATE_OFFICEDOC_RELATIONSTYPE( "slideMaster" ) );
+                    OUString aMasterFragmentPath = xLayoutRelations->getFragmentPathFromFirstType( CREATE_OFFICEDOC_RELATION_TYPE( "slideMaster" ) );
                     if( aMasterFragmentPath.getLength() )
                     {
                         // check if the corresponding masterpage+layout has already been imported
@@ -200,7 +199,7 @@ void PresentationFragmentHandler::endDocument() throw (SAXException, RuntimeExce
                                 pMasterPersistPtr = *aIter;
                                 break;
                             }
-                            aIter++;
+                            ++aIter;
                         }
                         if ( aIter == rMasterPages.end() )
                         {   // masterpersist not found, we have to load it
@@ -221,7 +220,7 @@ void PresentationFragmentHandler::endDocument() throw (SAXException, RuntimeExce
                             FragmentHandlerRef xMasterFragmentHandler( new SlideFragmentHandler( rFilter, aMasterFragmentPath, pMasterPersistPtr, Master ) );
 
                             // set the correct theme
-                            OUString aThemeFragmentPath = xMasterFragmentHandler->getFragmentPathFromFirstType( CREATE_OFFICEDOC_RELATIONSTYPE( "theme" ) );
+                            OUString aThemeFragmentPath = xMasterFragmentHandler->getFragmentPathFromFirstType( CREATE_OFFICEDOC_RELATION_TYPE( "theme" ) );
                             if( aThemeFragmentPath.getLength() > 0 )
                             {
                                 std::map< OUString, oox::drawingml::ThemePtr >& rThemes( rFilter.getThemes() );
@@ -247,11 +246,13 @@ void PresentationFragmentHandler::endDocument() throw (SAXException, RuntimeExce
                 }
 
                 // importing slide page
-                pSlidePersistPtr->setMasterPersist( pMasterPersistPtr );
-                pSlidePersistPtr->setTheme( pMasterPersistPtr->getTheme() );
-                Reference< drawing::XMasterPageTarget > xMasterPageTarget( pSlidePersistPtr->getPage(), UNO_QUERY );
-                if( xMasterPageTarget.is() )
-                    xMasterPageTarget->setMasterPage( pMasterPersistPtr->getPage() );
+                if (pMasterPersistPtr.get()) {
+                    pSlidePersistPtr->setMasterPersist( pMasterPersistPtr );
+                    pSlidePersistPtr->setTheme( pMasterPersistPtr->getTheme() );
+                    Reference< drawing::XMasterPageTarget > xMasterPageTarget( pSlidePersistPtr->getPage(), UNO_QUERY );
+                    if( xMasterPageTarget.is() )
+                        xMasterPageTarget->setMasterPage( pMasterPersistPtr->getPage() );
+                }
                 rFilter.getDrawPages().push_back( pSlidePersistPtr );
                 rFilter.setActualSlidePersist( pSlidePersistPtr );
                 importSlide( xSlideFragmentHandler, pSlidePersistPtr );
@@ -259,7 +260,7 @@ void PresentationFragmentHandler::endDocument() throw (SAXException, RuntimeExce
                 pSlidePersistPtr->createXShapes( rFilter );
 
                 // now importing the notes page
-                OUString aNotesFragmentPath = xSlideFragmentHandler->getFragmentPathFromFirstType( CREATE_OFFICEDOC_RELATIONSTYPE( "notesSlide" ) );
+                OUString aNotesFragmentPath = xSlideFragmentHandler->getFragmentPathFromFirstType( CREATE_OFFICEDOC_RELATION_TYPE( "notesSlide" ) );
                 if( aNotesFragmentPath.getLength() > 0 )
                 {
                     Reference< XPresentationPage > xPresentationPage( xSlide, UNO_QUERY );
@@ -281,12 +282,11 @@ void PresentationFragmentHandler::endDocument() throw (SAXException, RuntimeExce
                 }
             }
         }
-        ResolveTextFields( rFilter ); 
+        ResolveTextFields( rFilter );
     }
     catch( uno::Exception& )
     {
-        OSL_ENSURE( false,
-            (rtl::OString("oox::ppt::PresentationFragmentHandler::EndDocument(), "
+        OSL_FAIL( (rtl::OString("oox::ppt::PresentationFragmentHandler::EndDocument(), "
                     "exception caught: ") +
             rtl::OUStringToOString(
                 comphelper::anyToString( cppu::getCaughtException() ),
@@ -305,30 +305,30 @@ Reference< XFastContextHandler > PresentationFragmentHandler::createFastChildCon
     Reference< XFastContextHandler > xRet;
     switch( aElementToken )
     {
-    case NMSP_PPT|XML_presentation:
-    case NMSP_PPT|XML_sldMasterIdLst:
-    case NMSP_PPT|XML_notesMasterIdLst:
-    case NMSP_PPT|XML_sldIdLst:
+    case PPT_TOKEN( presentation ):
+    case PPT_TOKEN( sldMasterIdLst ):
+    case PPT_TOKEN( notesMasterIdLst ):
+    case PPT_TOKEN( sldIdLst ):
         break;
-    case NMSP_PPT|XML_sldMasterId:
-        maSlideMasterVector.push_back( xAttribs->getOptionalValue( NMSP_RELATIONSHIPS|XML_id ) );
+    case PPT_TOKEN( sldMasterId ):
+        maSlideMasterVector.push_back( xAttribs->getOptionalValue( R_TOKEN( id ) ) );
         break;
-    case NMSP_PPT|XML_sldId:
-        maSlidesVector.push_back( xAttribs->getOptionalValue( NMSP_RELATIONSHIPS|XML_id ) );
+    case PPT_TOKEN( sldId ):
+        maSlidesVector.push_back( xAttribs->getOptionalValue( R_TOKEN( id ) ) );
         break;
-    case NMSP_PPT|XML_notesMasterId:
-        maNotesMasterVector.push_back( xAttribs->getOptionalValue(NMSP_RELATIONSHIPS|XML_id ) );
+    case PPT_TOKEN( notesMasterId ):
+        maNotesMasterVector.push_back( xAttribs->getOptionalValue(R_TOKEN( id ) ) );
         break;
-    case NMSP_PPT|XML_sldSz:
+    case PPT_TOKEN( sldSz ):
         maSlideSize = GetSize2D( xAttribs );
         break;
-    case NMSP_PPT|XML_notesSz:
+    case PPT_TOKEN( notesSz ):
         maNotesSize = GetSize2D( xAttribs );
         break;
-    case NMSP_PPT|XML_custShowLst:
+    case PPT_TOKEN( custShowLst ):
         xRet.set( new CustomShowListContext( *this, maCustomShowList ) );
         break;
-    case NMSP_PPT|XML_defaultTextStyle:
+    case PPT_TOKEN( defaultTextStyle ):
         xRet.set( new TextListStyleContext( *this, *mpTextListStyle ) );
         break;
     }
@@ -378,7 +378,7 @@ bool PresentationFragmentHandler::importSlide( const FragmentHandlerRef& rxSlide
                 xPropertySet->setPropertyValue( sIsHeaderVisible, Any( aHeaderFooter.mbHeader ) );
             xPropertySet->setPropertyValue( sIsFooterVisible, Any( aHeaderFooter.mbFooter ) );
             xPropertySet->setPropertyValue( sIsDateTimeVisible, Any( aHeaderFooter.mbDateTime ) );
-            xPropertySet->setPropertyValue( sIsPageNumberVisible, Any( aHeaderFooter.mbSlideNumber ) );	
+            xPropertySet->setPropertyValue( sIsPageNumberVisible, Any( aHeaderFooter.mbSlideNumber ) );
         }
         catch( uno::Exception& )
         {
@@ -390,3 +390,4 @@ bool PresentationFragmentHandler::importSlide( const FragmentHandlerRef& rxSlide
 
 } }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
